@@ -118,12 +118,26 @@ class owlclass(owlobject):
         Generates a representation of the class using COOL CLIPS language
         :return:
         """
+        if RDFS.label in self.attributes:
+            name = self.attributes[RDFS.label]
+            if name  == '':
+                name = self.name
+        else:
+            name = self.name   
+        name = name.replace(' ', '_')
         comment = self.attributes[RDFS.comment].strip("\n").strip(" ").strip("\n")
-        s = f'(defclass {self.name} "{comment}"\n' if comment != '' else f'(defclass {self.name}\n'
+        s = f'(defclass {name} "{comment}"\n' if comment != '' else f'(defclass {name}\n'
         if self.parent is None:
             s += '    (is-a USER)\n'
         else:
-            s += f'    (is-a {self.parent.name})\n'
+            if  RDFS.label in self.parent.attributes:
+                pname = self.parent.attributes[RDFS.label]
+                if pname  == '':
+                    pname = self.parent.name
+            else:
+                pname = self.parent.name
+            pname = pname.replace(' ', '_')
+            s += f'    (is-a {pname})\n'
         s += '    (role concrete)\n    (pattern-match reactive)\n'
         for p in self.properties:
             s += '    ' + self.properties[p].toCLIPS()
@@ -148,7 +162,7 @@ class owlprop(owlobject):
 
     def get_functional(self, graph):
         """
-        Checks if the property is defined as funcional (cardinality 1)
+        Checks if the property is defined as functional (cardinality 1)
         :param graph:
         :return:
         """
@@ -162,10 +176,15 @@ class owlprop(owlobject):
 
     def toCLIPS(self):
         comment = self.attributes[RDFS.comment].strip("\n").strip(" ").strip("\n")
-        if self.functional:
-            s = f'(single-slot {self.name}'
+        if RDFS.label in self.attributes:
+            name = self.attributes[RDFS.label]
         else:
-            s = f'(multislot {self.name}'
+            name = self.name
+        name = name.replace(' ', '_')
+        if self.functional:
+            s = f'(single-slot {name}'
+        else:
+            s = f'(multislot {name}'
         if self.attributes[RDF.type] in [OWL.DatatypeProperty, OWL.FunctionalProperty]:
             if self.attributes[RDFS.range] in datatypes:
                 s += f'\n        (type {datatypes[self.attributes[RDFS.range]]})'
@@ -224,8 +243,12 @@ class owlinstance(owlobject):
         """
         level = '    '
         comment = self.attributes[RDFS.comment].strip("\n").strip(" ").strip("\n")
-
-        s = f"([{self.name}] of {self.chop(self.iclass)}"
+        if RDFS.label in self.attributes:
+            name = self.attributes[RDFS.label]
+        else:
+            name = self.name  
+        name = name.replace(' ', '_') 
+        s = f"([{name}] of {self.chop(self.iclass)}"
         pr = '\n'
         for p in self.properties:
             lval = self.properties[p][0]
